==> glpi-10.0.1.tgz: glpi/install/migrations/update_9.5.x_to_10.0.0/contracts.php <==
<?php

/**
 * ---------------------------------------------------------------------
 *
 * GLPI - Gestionnaire Libre de Parc Informatique
 *
 * http://glpi-project.org
 *
 * @copyright 2015-2022 Teclib' and contributors.
 * @copyright 2003-2014 by the INDEPNET Development Team.
 * @licence   https://www.gnu.org/licenses/gpl-3.0.html
 *
 * ---------------------------------------------------------------------
 *
 * LICENSE
 *
 * This file is part of GLPI.
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <https://www.gnu.org/licenses/>.
 *
 * ---------------------------------------------------------------------
 */

/**
 * @var Migration $migration
 */

$migration->changeField(Contract::getTable(), 'use_monday', 'use_sunday', 'bool');
$migration->dropKey(Contract::getTable(), 'use_monday');
$migration->changeField(Contract::getTable(), 'monday_begin_hour', 'sunday_begin_hour', 'time', [
    'value'  => '00:00:00'
]);
$migration->changeField(Contract::getTable(), 'monday_end_hour', 'sunday_end_hour', 'time', [
    'value'  => '00:00:00'
]);
$migration->migrationOneTable(Contract::getTable());
$migration->addKey(Contract::getTable(), 'use_sunday');

==> glpi-10.0.11.tgz: glpi/install/migrations/update_9.5.x_to_10.0.0/contracts.php <==
<?php

/**
 * ---------------------------------------------------------------------
 *
 * GLPI - Gestionnaire Libre de Parc Informatique
 *
 * http://glpi-project.org
 *
 * @copyright 2015-2023 Teclib' and contributors.
 * @copyright 2003-2014 by the INDEPNET Development Team.
 * @licence   https://www.gnu.org/licenses/gpl-3.0.html
 *
 * ---------------------------------------------------------------------
 *
 * LICENSE
 *
 * This file is part of GLPI.
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <https://www.gnu.org/licenses/>.
 *
 * ---------------------------------------------------------------------
 */

/**
 * @var \Migration $migration
 */

$migration->changeField(Contract::getTable(), 'use_monday', 'use_sunday', 'bool');
$migration->dropKey(Contract::getTable(), 'use_monday');
$migration->changeField(Contract::getTable(), 'monday_begin_hour', 'sunday_begin_hour', 'time', [
    'value'  => '00:00:00'
]);
$migration->changeField(Contract::getTable(), 'monday_end_hour', 'sunday_end_hour', 'time', [
    'value'  => '00:00:00'
]);
$migration->migrationOneTable(Contract::getTable());
$migration->addKey(Contract::getTable(), 'use_sunday');
